@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Number::Tolerant;
 # ABSTRACT: tolerance ranges for inexact numbers
-$Number::Tolerant::VERSION = '1.707';
+$Number::Tolerant::VERSION = '1.708';
 use Sub::Exporter::Util;
 use Sub::Exporter 0.950 -setup => {
   exports => { tolerance => Sub::Exporter::Util::curry_class('new'), },
@@ -138,7 +138,7 @@ sub _boot_up {
     map { "Number::Tolerant::Type::$_" }
     qw(
       constant    infinite        less_than
-      more_than   offset          or_less 
+      more_than   offset          or_less
       or_more     plus_or_minus   plus_or_minus_pct
       to
     );
@@ -162,7 +162,7 @@ sub new {
       defined $guts->{min} and defined $guts->{max} and
       $guts->{min} == $guts->{max} and
       not $guts->{constant}
-    ) { 
+    ) {
       @_ = ($class, $guts->{min});
       goto &new;
     }
@@ -410,7 +410,12 @@ use overload
   'bool'   => sub { 1 },
   '0+'     => 'numify',
   '<=>' => sub {
-    $_[2] ? ($_[1] <=> $_[0]->{value}) : ($_[0]->{value} <=> $_[1])
+    my $rv = $_[0] == $_[1] ? 0
+           : $_[0] <  $_[1] ? -1
+           : $_[0] >  $_[1] ? 1
+           : die "impossible";
+    $rv *= -1 if $_[2];
+    return $rv;
   },
   '""' => 'stringify',
   '==' => '_num_eq',
@@ -466,7 +471,7 @@ use overload
 #pod
 #pod =item * Allow translation into forms not originally used:
 #pod
-#pod  my $range    = tolerance(9 => to => 17); 
+#pod  my $range    = tolerance(9 => to => 17);
 #pod  my $range_pm = $range->convert_to('plus_minus');
 #pod  $range->stringify_as('plus_minus_pct');
 #pod
@@ -525,7 +530,7 @@ Number::Tolerant - tolerance ranges for inexact numbers
 
 =head1 VERSION
 
-version 1.707
+version 1.708
 
 =head1 SYNOPSIS
 
@@ -748,7 +753,7 @@ defined in Number::Tolerant::Type.  If it does not, an exception is thrown.
 
 =item * Allow translation into forms not originally used:
 
- my $range    = tolerance(9 => to => 17); 
+ my $range    = tolerance(9 => to => 17);
  my $range_pm = $range->convert_to('plus_minus');
  $range->stringify_as('plus_minus_pct');
 
